@@ -43,18 +43,19 @@ public:
         connect(qGuiApp, &QGuiApplication::paletteChanged, this, &StyleSingleton::refresh);
 
 #ifndef Q_OS_ANDROID
-        // Use DBus in order to listen for kdeglobals changes directly, as the
+        // Use DBus in order to listen for settings changes directly, as the
         // QApplication doesn't expose the font variants we're looking for,
         // namely smallFont.
         QDBusConnection::sessionBus().connect(QString(),
-                                              QStringLiteral("/KGlobalSettings"),
-                                              QStringLiteral("org.kde.KGlobalSettings"),
-                                              QStringLiteral("notifyChange"),
+                                              QStringLiteral("/KDEPlatformTheme"),
+                                              QStringLiteral("org.kde.KDEPlatformTheme"),
+                                              QStringLiteral("refreshFonts"),
                                               this,
                                               SLOT(notifyWatchersConfigurationChange()));
 #endif
 
         connect(qGuiApp, &QGuiApplication::fontDatabaseChanged, this, &StyleSingleton::notifyWatchersConfigurationChange);
+        connect(qGuiApp, &QGuiApplication::fontChanged, this, &StyleSingleton::notifyWatchersConfigurationChange);
 
         /* QtTextRendering uses less memory, so use it in low power mode.
          *
@@ -83,6 +84,26 @@ public:
         }
 
         QQuickWindow::setTextRenderType(defaultTextRenderType);
+
+        smallFont = loadSmallFont();
+    }
+
+    QFont loadSmallFont() const
+    {
+        KSharedConfigPtr ptr = KSharedConfig::openConfig();
+        KConfigGroup general(ptr->group("general"));
+
+        return general.readEntry("smallestReadableFont", []() {
+            auto smallFont = qApp->font();
+#ifndef Q_OS_WIN
+            if (smallFont.pixelSize() != -1) {
+                smallFont.setPixelSize(smallFont.pixelSize() - 2);
+            } else {
+                smallFont.setPointSize(smallFont.pointSize() - 2);
+            }
+#endif
+            return smallFont;
+        }());
     }
 
     void refresh()
@@ -177,14 +198,17 @@ public:
 
     Q_SLOT void notifyWatchersConfigurationChange()
     {
+        smallFont = loadSmallFont();
         for (auto watcher : qAsConst(watchers)) {
-            watcher->syncFont();
+            watcher->setSmallFont(smallFont);
+            watcher->setDefaultFont(qApp->font());
         }
     }
 
     KColorScheme buttonScheme;
+    QFont smallFont;
 
-    QVector<QPointer<PlasmaDesktopTheme>> watchers;
+    QVector<PlasmaDesktopTheme *> watchers;
 
 private:
     QHash<QPair<Kirigami::PlatformTheme::ColorSet, QPalette::ColorGroup>, Colors> m_cache;
@@ -210,7 +234,9 @@ PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
 
     (*s_style)->watchers.append(this);
 
-    syncFont();
+    setDefaultFont(qGuiApp->font());
+    setSmallFont((*s_style)->smallFont);
+
     syncWindow();
     syncColors();
 }
@@ -248,23 +274,6 @@ void PlasmaDesktopTheme::syncWindow()
     }
 }
 
-void PlasmaDesktopTheme::syncFont()
-{
-    KSharedConfigPtr ptr = KSharedConfig::openConfig();
-    KConfigGroup general(ptr->group("general"));
-    setSmallFont(general.readEntry("smallestReadableFont", []() {
-        auto smallFont = qApp->font();
-        if (smallFont.pixelSize() != -1) {
-            smallFont.setPixelSize(smallFont.pixelSize() - 2);
-        } else {
-            smallFont.setPointSize(smallFont.pointSize() - 2);
-        }
-        return smallFont;
-    }()));
-
-    setDefaultFont(qGuiApp->font());
-}
-
 QIcon PlasmaDesktopTheme::iconFromTheme(const QString &name, const QColor &customColor)
 {
 #ifndef Q_OS_ANDROID
@@ -366,7 +375,6 @@ void PlasmaDesktopTheme::syncColors()
 bool PlasmaDesktopTheme::event(QEvent *event)
 {
     if (event->type() == Kirigami::PlatformThemeEvents::DataChangedEvent::type) {
-        syncFont();
         syncColors();
     }
 
